pub trait MergeState {
type A;
type B;
// Required methods
fn a_slice(&self) -> &[Self::A];
fn b_slice(&self) -> &[Self::B];
}Expand description
The read part of the merge state that is needed for the binary merge algorithm it just needs random access for the remainder of a and b
Very often A and B are the same type, but this is not strictly necessary
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".